#
# spec file for package ekiga
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define with_evolution 1
%define with_gstreamer_0_10 0

Name:           ekiga
Version:        4.0.1
Release:        10.2
Summary:        A GNOME based SIP/H323 teleconferencing application
License:        SUSE-GPL-2.0-with-openssl-exception
Group:          Productivity/Telephony/SIP/Clients
Url:            http://www.ekiga.org/
Source:         http://download.gnome.org/sources/ekiga/4.0/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM boost-configure.patch schwab@suse.de -- AX_BOOST_BASE: add aarch64 to the list of lib64 architectures
Patch:          boost-configure.patch
BuildRequires:  boost-devel
BuildRequires:  cyrus-sasl-devel
BuildRequires:  dbus-1-glib-devel
%if %{with_evolution}
BuildRequires:  evolution-data-server-devel
%endif
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gconf2-devel
BuildRequires:  gnome-doc-utils-devel
BuildRequires:  gnome-icon-theme >= 3.0.0
%if %{with_gstreamer_0_10}
BuildRequires:  gstreamer-0_10-plugins-base-devel
%endif
BuildRequires:  gtk2-devel
BuildRequires:  intltool
BuildRequires:  libavahi-glib-devel
BuildRequires:  libnotify-devel
BuildRequires:  libopal-devel >= 3.10.10
BuildRequires:  libpt-devel >= 2.10.10
BuildRequires:  libsigc++2-devel
BuildRequires:  libsoup-devel
BuildRequires:  libv4l-devel
BuildRequires:  openldap2-devel
BuildRequires:  translation-update-upstream
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(xv)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
PreReq:         filesystem /usr/bin/touch gconf2
Provides:       gnomemeeting
Obsoletes:      gnomemeeting
%if ! %{with_evolution}
# In case we cannot build the evolution plugin, we obsolete the sub package
Obsoletes:      ekiga-plugins-evolution < %{version}
%endif
Recommends:     %{name}-lang
%gconf_schemas_prereq

%description
Ekiga (formely known as GnomeMeeting) is an open source VoIP and video
conferencing application for GNOME. Ekiga uses both the H.323 and SIP
protocols. It supports many audio and video codecs, and is
interoperable with other SIP compliant software and also with Microsoft
NetMeeting.

%if %{with_gstreamer_0_10}
%package -n ekiga-plugins-gstreamer
Summary:        Gstreamer plugin for %{name}
Group:          System/Libraries
Supplements:    packageand(ekiga:pulseaudio)

%description -n ekiga-plugins-gstreamer
This plugin enables gstreamer support in %{name}.
%endif

%if %{with_evolution}
%package -n ekiga-plugins-evolution
Summary:        Evolution plugin for %{name}
Group:          System/Libraries
Supplements:    packageand(ekiga:evolution-data-server)

%description -n ekiga-plugins-evolution
This plugin enables evolution support in %{name}.
%endif

%lang_package
%prep
%setup -q
%patch -p1
translation-update-upstream

%build
%configure \
    --disable-schemas-install \
    --disable-scrollkeeper \
    --enable-dbus \
%if %{with_gstreamer_0_10}
    --enable-gstreamer \
%endif
    --enable-xcap \
    --enable-avahi \
%if %{with_evolution}
    --enable-eds
%else
    --disable-eds
%endif
make %{?_smp_mflags}

%install
%makeinstall
find %{buildroot} -name '*.la' -delete -print
%find_gconf_schemas
%find_lang %{name} %{?no_lang_C}
cat %{name}.schemas_list >%{name}.lst
%suse_update_desktop_file %name
%fdupes $RPM_BUILD_ROOT

%pre -f %{name}.schemas_pre

%post
%desktop_database_post
%icon_theme_cache_post

%preun -f %{name}.schemas_preun

%posttrans -f %{name}.schemas_posttrans

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files -f %{name}.lst
%defattr(-,root,root)
%doc ChangeLog README FAQ
%dir %{_datadir}/gnome/
%dir %{_datadir}/gnome/help/
%dir %{_datadir}/gnome/help/%{name}/
%doc %{_datadir}/gnome/help/%{name}/C/
%dir %{_datadir}/omf/
%dir %{_datadir}/omf/%{name}/
%doc %{_datadir}/omf/%{name}/%{name}-C.omf
%dir %{_libdir}/%{name}/
%dir %{_libdir}/%{name}/%{version}/
%dir %{_libdir}/%{name}/%{version}/plugins/
%{_bindir}/*
%{_datadir}/applications/ekiga.desktop
%{_datadir}/dbus-1/services/*.service
%{_datadir}/icons/hicolor/*/apps/ekiga.png
%{_datadir}/pixmaps/ekiga
%{_datadir}/sounds/ekiga
%{_libdir}/ekiga/%{version}/libekiga.so
%{_libdir}/ekiga/%{version}/plugins/libgmavahi.so
%{_libdir}/ekiga/%{version}/plugins/libgmldap.so
%{_libdir}/ekiga/%{version}/plugins/libgmlibnotify.so
%{_libdir}/ekiga/%{version}/plugins/libgmresource_list.so
%{_libdir}/ekiga/%{version}/plugins/libgmxcap.so
%{_mandir}/man1/ekiga.1*

%if %{with_gstreamer_0_10}
%files -n ekiga-plugins-gstreamer
%defattr(-,root,root)
%{_libdir}/ekiga/%{version}/plugins/libgmgstreamer.so
%endif

%if %{with_evolution}
%files -n ekiga-plugins-evolution
%defattr(-,root,root)
%{_libdir}/ekiga/%{version}/plugins/libgmevolution.so
%endif

%files lang -f %{name}.lang

%changelog
* Thu Jun  5 2014 fcrozat@suse.com
- Add macro to allow disabling gstreamer 0.10 dependency and
  disable it by default (ekiga is pulling gstreamer 1.0 internally)
- Enable evolution-data-server support
- Fix bad copy-paste in Supplements in eds subpackage.
* Mon Feb 17 2014 ro@suse.de
- expand boost-configure.patch for ppc64le
* Mon Jun 17 2013 schwab@suse.de
- boost-configure.patch: fix boost configure check
* Sun Jun 16 2013 jengelh@inai.de
- Add explicit cyrus-sasl-devel BuildRequires: It used to be pulled
  in by openldap-devel.
* Tue Feb 26 2013 dimstar@opensuse.org
- Update to version 4.0.1:
  + User-visible fixes:
  - Fix crash when quitting ekiga while receiving presence
    information
  - Fix crash when quitting ekiga right after starting it (before
    STUN ending)
  - Fix crash when disabling an account while icons in roster are
    changing
  - Fix crash when receiving call a second time
  - Fix crash in XML parsing in case of malicious code
  - Fix increasing CPU usage afer hours of usage caused by
    endless OPTIONS
  - Several fixes for H.323
  - Fix registration for registrars accepting the last Contact
    item offered
  - Allow to change the REGISTER compatibility mode of an
    existing registration
  - Fix impossibility to hangup active call after a missed call
  - Fix busy or call forwarding on busy occuring when connection
    is released
  - Fix subscribing/unsubscribing when enabling and disabling SIP
    accounts
  - Do not show is-typing messages sent by other programs during
    chatting
  - Stop ongoing registration when remove account
  - Use meaningful names for ALSA sub-devices
  - Allow to enter contact addresses without host part, and
    choose the host later
  - Increase number of characters shown in device names
  - Use a better icon for call history in addressbook
  - Show the address instead of "telephoneNumber" in addressbook
  - Deactivate NullAudio ptlib's device for audio input too
  - Do not send OPTIONS messages once the account is disabled
  - Hide the main window immediately on exit
  - Handle xa status as away
  - Fix debugging message when registering
  - Fix race condition leading to duplicate entry in call history
  - Fix incoming call if two INVITE's in a fork arrive very close
    together
  - Use correct username in OPTIONS messages
  - Allow to have message waiting indication even if asterisk's
    vmexten is off
  - Send OPTION only on the right interface
  - Fix buttons direction in dialpad for RTL languages
  - Fix aborting RTP receiver with Polycom HDX8000
  - Fix possible incorrect jitter calculation for RTCP
  - Only kill REGISTER/SUBSCRIBE forks if a "try again" response
    is received
  + Various other fixes.
  + Windows port fixes.
  + Updated translations.
- Introduce with_evolution, currently set to 0, as ekiga is not
  compatible at this moment with evolution 3.8. The effects are:
  + Conditionall BuildRequire evolution-data-server-devel (1).
  + Conditionall pass --disable-eds (0) or --enable-eds (1) to
    configure.
  + Create ekiga-plugins-evolution sub package (1).
  + Obsolete ekiga-plugins-evolution subpackage from the main
    package (0).
- Replace openldap2 BuildRequires with openldap2-devel: As
  evolution-data-server pulls it in, it was never spotted to be
  wrong.
* Mon Dec  3 2012 dimstar@opensuse.org
- Update to version 4.0.0:
  + Major overhaul of the main window
  + Use gnome icons instead of ekiga's own
  + Re-add back H264 and H263+ video plugins
  + New pulse audio plugin (in ptlib)
  + New audio codecs: SILK (used by skype), G.722.1 (aka Siren 7),
    G.722.2 (aka GSM-AMR Wide band)
  + Fix H.323 gatekeeper support
  + Call auto-answer
  + Support for handling multiple video streams (H.239)
  + Use spinner effect during ringing on the other party
  + Unregister accounts when quitting
  + Set presence to offline upon quitting
  + Faster startup by not getting canonical name of servers
  + Fixes for Contact field during registration:
  - Use two additional compatibility mode for some bogus
    registrars
  - Fix order of items in Contact field
  + Add tooltips to various windows and dialog boxes
  + Adjust defaults (show offline users, use picture-in-picture)
  + Jabber/XMPP and GStreamer fixes
  + [windows] Support mingw-w64 and its own headers for building
  + See NEWS file for more details.
- Add gnome-icon-theme BuildRequires: new verified dependency.
- Pass --enable-avahi to configure: the default has been changed.
* Sat Sep  8 2012 vuntz@opensuse.org
- Add libv4l-devel BuildRequires to enable video4linux support.
* Mon Aug 27 2012 dimstar@opensuse.org
- Update to version 3.9.90:
  + Major user-visible fixes:
  - Major overhaul of the main window
  - Add a new page in assistant with an introduction to accounts
  - Unregister accounts when quitting
  - Auto-answering to calls (in 3.3.0 in fact)
  - Faster startup by not getting canonical name of servers
  - Partial support of H.239
  - Speed up registration when packets get lost
  - Use optimised flags for H.264 video decoder
  - Limit history book to 100 entries, fixing some crashes
  - Improvements to the still experimental loudmouth plugin
  - Fix chat messages are received several times if several
    network interfaces
  - Set presence to offline upon quitting
  - Blacklist NSE, fixing registration with some registrars, such
    as Eutelia
  - Canonise address introduced when adding/editing a contact in
    roster
  - Use gnome icons instead of ekiga's own
  - Some fixes on online/offline presence
  - Disable IPv6 by default, which caused some problems (will be
    enabled later)
  - Fix a race condition in PulseAudio plugin
  - Initial support for handling multiple video streams (H.239
  + Protocol fixes:
  - Fixes for Contact field during registration:
    . Use two additional compatibility mode for some bogus
    registrars
    . Fix order of items in Contact field
  - Fix presence with asterisk
  - Fixes on INVITE packets in some corner cases
  - Fix own presence stopping to be sent after some time
  - Fix loading of codecs without an encoding name, e.g.
    MS-IMA-ADPCM
  - Use SIP OPTIONS to refresh NAT bindings
  - Numerous other fixes, especially on H264 support
  + Windows fixes.
  + Build fixes.
  + Updated translations.
- Drop ekiga-gcc47.patch: fixed upstream.
- Drop ekiga-libboost.patch: more complete fixed upstream.
- Drop libtool BuildRequires and call to autoreconf: we no longer
  carry any patch.
* Sat Jul 28 2012 dvaleev@suse.com
- Add ekiga-libboost.patch: fix libbost detection on ppc64
- Add libtool BuildRequires and call autoreconf, as the above patch
  touches the build system.
* Wed Jun  6 2012 cfarrell@suse.com
- license update: SUSE-GPL-2.0-with-openssl-exception
  Ekiga has an exception for linking against e.g. openssl
* Fri May 18 2012 zaitor@opensuse.org
- Update to version 3.3.2:
  + User-visible fixes:
  - Re-add back H264 and H263+ video plugins
  - Fix presence in case of several tuples
  - Fix presence when receiving old presentity type without note
  - Re-add contact limited compatibility mode for bogus
    registrars
  - Fix leaking the opal account store in the assistant
  - Make Enter key in roster (contact list) make a call
  - Fix infinite loops in the loudmouth presentity code
  - Add mnemonics to buttons in Accounts dialog box
  - Fix _dl_close failed assertion at quit
  + Distributor-visible changes:
  - Re-add back H264 and H263+ video plugins
  + Build fixes:
  - Fix generation of po translation files
  - Fix build with -Wl,-z,defs of xcap plugin
  - Check for ptlib expat support during configure
  + Updated translations.
- Changes from version 3.3.1:
  + User-visible fixes:
  - Fix crash when no audio device exists
  - Fix crash in avahi when peer goes offline
  - Add back presence, lost in 3.3.0
  - Improve failure indication when sending instant messages
  - Improve Enter key usage in chat
  - Improvements to still partial support for IPv6
  - Fix "PTLib assumes all Ethernet devices are named ethX"
  - Fix crash in __gnu_cxx:bitmap_allocator using newer gcc
  - Use DNS SRV caching (fix ekiga takes minutes to start)
  - New audio codecs: SILK (used by skype), G.722.1 (aka Siren 7)
    , G.722.2 (aka GSM-AMR Wide band)
  - Improve audio accuracy on some audio cards
  - Ask user about new ringing device too when pluging an audio
    output device
  - Small reduction of assistant window size, useful for small
    screens
  - Add tooltips to various windows and dialog boxes
  - Fix addressbook key in schemas
  - Propose to add an ekiga.net book only when it hasn't one
    already
  - Remove obsolete reencoding (to utf8) of device names on Linux
  - Made creating an XMPP/Jabber account nicer
  - Usability improvements to notification dialog
  - other fixes
  + Protocol fixes:
  - Fix "Ekiga ignores Service-Route recommended by server"
  - Fix "SIP: incoming call failing when using localhost"
  - Reset SIP Contacts "limited" workaround if it does not work
  - other SIP/H.323 fixes
  + Build fixes:
  - Fix compatibility with modern autoconf
  - Remove obsolete SSL2 support
  - Fix build with binutils-gold and with -Wl,-z,defs
  - Fix gdu build option
  - Fix loudmouth build option and comment for gconf build option
  - Made configure honor ACLOCAL_FLAGS
  - Fix compilation of xcap plugin
  - Fix compilation errors with GTK 2.24
  - Fix building on FreeBSD
  - Code cleanup
  + Updated translations.
- Changes from version 3.3.0:
  + Distributor-specific changes:
  - New pulse audio plugin (in ptlib)
  - ekiga is now split between one executable, one library and
    two plugins (evolution and ldap).  This means that
    evolution-data-server for ex. can be used during building,
    but is not mandatory upon execution. As a consequence, this
    allows to install ekiga without e-d-s and its many
    dependencies.
  - Depend on boost instead of sigc++
  - Update to the new libnotify 0.7.0 library
  + User-visible changes:
  - Various SIP/H.323 fixes
  - When a registrar refuses several Contact-s during
    registration, automatically retry registration with only one
    Contact (previous "%%limit" workaround)
  - Fix "Ekiga crashes when restart a holding call established by
    H.323"
  - Fix "Cseq value is empty, malformed packet as per Wireshark"
  - Fix "Text on first page of assistant is sometimes not shown"
  - Fix DTMF signaling
  - Fix pre-fill account name and password in assistant
  - Fix dialog info presence handling
  - Add a TOS field config option
  - Update the "Contact" menu when selecting a heap or a group
  - Distribute a 24x24 icon too
  - Always honour show_hidden setting for main window
  - Adjust defaults (show offline users, use picture-in-picture)
  + Developer-specific changes:
  - Many code cleanups
  - Various deprecated code replaced with current equivalents
  + Updated translations.
- Drop ekiga-libnotify_gtk.patch and ekiga-libnotify07.patch, fixed
  upstream.
- Add ekiga-gcc47.pach, fix build with gcc47.
- New packages: ekiga-plugins-gstreamer and ekiga-plugins-evolution
- New BuildRequires:  boost-devel. New dependency that configure
  checks for.
* Sun Feb 19 2012 dimstar@opensuse.org
- Add pkgconfig(xv) BuildRequires: this used to be pulled in by
  something else, but the relayout of xorg-x11 packages changed
  that.
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Mon Sep  5 2011 vuntz@opensuse.org
- Remove service usage, following the new consensus on Factory
  packaging.
* Sun Sep  4 2011 zaitor@opensuse.org
- Add explicit dbus-1-glib-devel BuildRequires: it used to be
  brought in by something else before.
* Fri Apr  8 2011 dimstar@opensuse.org
- Add ekiga-libnotify07.patch: fix build with libnotify 0.7. Patch
  taken from upstream git, commit 6a964b.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Remove "touch var/adm/SuSEconfig/run-scrollkeeper-update" from
  %%postun: this won't do anything anymore.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Wed Dec 15 2010 vuntz@opensuse.org
- Own /usr/share/gnome and /usr/share/gnome/help to fix build.
* Wed Jul 28 2010 reddwarf@opensuse.org
- Update to version 3.2.7:
  + User-visible fixes:
  - Use NAT ports instead of local ports for RTP, fixing many
    connection issues
  - Add workaround for "In some cases ekiga answers always Busy
    Here"
  - Fix crash in the avahi code
  - Set the default audio and video devices
  - Fix Call buttons do not work
  - Add bpp16 (RGB16) support
  - Add partial support for IPv6
  - Fix number of users found on ekiga.net LDAP directory
  - Fix connection type setting in assistant
  - Use a decent connection type by default (DSL 128kb/s uplink)
  - Check off iLBC, CELT32, CELT48 and G722 audio codecs by
    default
  - Fix possible crash when PTLib code accessed by thread not
    created by PTlib
  - Fix issue when deleting a safe object
  - Fix possible NULL pointer access if get multiple NOTIFY
    messages on a REFER
  + Protocol fixes:
  - Fix strange issue with SIP call diversion (302 response) to
    the same endpoint
  - Change to only unregister those contact addresses we
    successfully registered
  - Fix incorrect change to AlertingPhase in H323
  - Change authentication failure to be fatal and SIP handler
    removed
  - Fix double authorisation failure leaving SIP handler in the
    wrong state
  - Fix SIP REFER completion on receiving NOTIFY with id
    parameter
  - Fix authentication issue when can get to SIP server via two
    interfaces
  - Fix address translation of REGISTER contact fields when STUN
    is not used
  - Fix locating correct authorisation credentials for INVITE
  - Fix correct test handling RFC3261/8.2.2.2 merged requests and
    other "multi-path" received INVITE requests
  - other minor fixes
  + Build fixes
  - Fix gdu (gnome-doc-utils) configure option
  - Replace deprecated functions in gtk >= 2.18
  - Fix build with binutils-gold
  - other minor build fixes
  + Windows port fixes
  + Updated translations.
- Change libpt2-devel and opal-devel BuildRequires to libpt-devel
  libopal-devel after package renaming.
- Remove unneeded db-devel, gnome-common, scrollkeeper, speex-devel
  BuildRequires.
- Add ekiga-libnotify_gtk.patch to fix build with recent libnotify.
- Do not add -fstack-protector -fexceptions to CFLAGS and CXXFLAGS.
* Tue Oct  6 2009 dimstar@opensuse.org
- Update to version 3.2.6:
  + Fix various crashes
  + Fixed freeze during packet write
  + Fixed "Lockup after a day of idle" in publishing code
  + Added "%%limit" workaround for registrars which refuse several
    contacts during registration
  + Fixed "Contacts never go offline"
  + Fixed "New SIP account mangles fields if Authentications User
    is empty"
  + Make sure the output device is set before a call
  + Fixed port handling when registering to a proxy with a
    non-standard port
  + Many protocol fixes
  + Various build fixes
  + Updated translations.
- Drop upstream included ekiga-libsoup2.27.90.patch and
  ekiga-no-return-in-nonvoid.patch.
- The update fixes registration issues with various SIP providers
  like 1und1 for example (which would deny registration with
  "403 Forbidden (No RFC 1918 IP allowed)".
* Tue Aug 25 2009 dimstar@opensuse.org
- Add ekiga-libsoup2.27.90.patch - Fix build with libsoup 2.27.90
- Add ekiga-no-return-in-nonvoid.patch.
* Sun Jul 19 2009 dominique-obs@leuenberger.net
- Update to version 3.2.5:
  + Fixed very low rate video transmission
  + Fixed possible crash in LDAP
  + Fixed possible crash in presence
  + Fixed simultaneous reads from different threads in jitter code
  + Fixed possible crash when idle
  + Fixed possible crash when accepting a call
  + Fixed possible deadlock in SIP handlers
  + Fixed possible freeze when calling out
  + Fixed URL displayed in the URI bar when calling out
  + Fixed crash when using G726-16 audio codec
  + Fixed multiple registrations with the same registrar using
    different user names
  + Allows user to choose system iLBC
  + Fixed window resizing in chat when entering very long words
  + Fixed linking of sbc plugin with libsamplerate
  + Fixed compilation with gtk 2.12
  + Fixed compilation with gcc 4.4
  + Windows and Solaris specific fixes
  + Added a small script, ekiga-debug-analyser, which only displays
    the packets exchanged from a Ekiga debug output
  + Other minor fixes
  + Updated translations.
* Wed May 20 2009 dominique-obs@leuenberger.net
- Update to version 3.2.4:
  + contains a fix for invalid OPAL and PTLIB recommended versions
- Changes from version 3.2.3:
  + Fixed remote uri not being shown in the uri bar when dialing
    out
- Changes from version 3.2.2:
  + Fixed a crash on some calls
- Changes from version 3.2.1:
  + Many bugs fixed. The following is a selection from NEWS.
  + Fixed various crashes
  + Many SIP-related fixes, see NEWS for details.
  + Migrate ekiga.net configuration from 3.0 to 3.2
  + Memory leaks.
  + Maintain window position on hiding/showing the main window
  + Fixed recognition of cameras with non-ascii characters
  + Fixed video I-frame detection
  + Fixed media format matching option additions
  + Fixed advanced rate controller support
  + Fixed popping frames problem when rate controller skips input
    frames
  + Fixed missing re-lock of mutex on jitter buffer shut down
  + Fixed gatekeeper discovery
  + Fixed possible assertion if the soundcard blocks and prevents
    the device to be closed
  + Fixed being able to switch off jitter buffer while still a
    thread reading from it
  + Don't stop a call from clearing due to lack of media just
    because a session has not received any packets
  + Improved the RTP stack performances
  + Fixed various video payload problems
  + Add numerous boundary checks to H.263 codec
  + Discard out of order packets, mode A frames that don't begin
    with a start code, and frames that don't begin with a start
    code in H.263 codec
  + Fixed initial H.323 call set up honouring the auto-start
    configuration for "don't offer"
  + Build fixes.
  + Updated translations.
- Drop ekiga-build-fix.patch and
  ekiga-crash-gstreamer-detection.patch: fixed upstream.
* Fri May  1 2009 vuntz@novell.com
- Add ekiga-crash-gstreamer-detection.patch to fix a crash on
  startup with the gstreamer device detection code.
* Wed Apr 29 2009 vuntz@novell.com
- Update to version 3.2.0:
  + Fix some NAT related issues (use internal port instead of
    external port in Cone NAT)
  + Uniformise detection of libnotify; fix compilation with mingw
  + Fix "URL completion combobox shows identical completions"
  + Fix "Assistant loosing values when going backward"
  + Fix GmConf settings when compiled with another package name
  + Fix unregistration of accounts
  + Fix build with -enable-kde
  + Fix OS X build
  + Fix a crash in chat
  + Updated translations.
- Changes from version 3.1.2:
  + Experimental features:
  - Significant improvements in IPv6 support
  - Gstreamer audio and video capture support near to be
    finished...
  + Removal of the old H.263 ffmpeg plug in and enhancement of the
    H.263-1998 plug in to take its place.
  + Allow compilation with CELT 0.4 and 0.5
  + Allow several ALSA devices to have the same name
  + STUN enabling/disabling has been readded to the GUI
  + Remove white spaces from the URI (useful when copy/paste)
  + Clear the URI edit box after a call
  + Fixed crash when clearing call history
  + Fix Windows compilation
  + Fixes for tarball generation
  + Fixed account data corruption when the authentication user name
    is left blank
  + Fixed possible crash when answering incoming calls
  + Fixed G.722 usage
  + Other various fixes, cleanups, removal of deprecated symbols
    etc.
  + Updated translations.
- Changes from 3.1.0:
  + Added support for G.722 and CELT audio wideband codecs
  + Added support for H.263
  + Added support for SIP dialog-info notifications, it allows
    being notified of incoming calls for the phones of your
    colleagues with software like Asterisk
  + Added support to disable STUN detection
  + Improved LDAP support in the address book, authentication is
    now possible
  + Killed the gconf_test_age test, Ekiga can now finally work with
    badly installed GConf schemas
  + More efficient memory handling using gmref_ptr, increases
    stability
  + Better handling of multiple network interfaces with dynamic
    addition and removal
  + libgnome is not required anymore when using GTK+ 2.14
  + Many code cleanups, new GObjects, ...
  + Work in progress : XCAP support, Resource List support,
    GStreamer audio and video capture support, ...
- Changes from 3.0.2:
  + Make sure sound events are played through the correct devices.
    (bgo#564370)
  + Fixed crash on missed call.
  + Do not show the assistant after an upgrade for which Ekiga was
    already successfully setup.
  + Added settings migration from Ekiga 2.0.x.
  + Allow answering/rejecting calls from the main window even if we
    use notifications.
  + Do not try refreshing SUBSCRIBE requests for which the 200 OK
    contains an expire time of 0.
  + Fixed sending ACK request to incorrect address when particular
    types of proxies are being used.
  + Fixed test for CANCEL receipt on INVITE clearing call.
  + Ignore multiple forked CANCEL messages.
  + Fixed issue with registration to a non-standard port.
  + Fixed restarting timers if get pathological response to a
    transaction with incorrect Cseq header field.
  + Fixed missing route set on SIP commands in a dialog when using
    outbound proxy.
- Add ekiga-build-fix.patch to fix build.
- Remove unneeded BuildRequires: SDL-devel, docbook_4,
  esound-devel, libdv, libgnomeui-devel, mozilla-nss-devel,
  perl-XML-Parser
- Add BuildRequires: gconf2-devel,
  gstreamer-0_10-plugins-base-devel, gtk2-devel, libsoup-devel
- Do not call intltoolize and autoreconf since it's not needed.
- Pass --enable-gstreamer and --enable-xcap to configure.
- Do not add categories that were arlready there to the desktop
  file.
- Do not add DocPath to the desktop file since yelp doesn't needed
  this.
- Clean up file list with _datadir and friends.
- Do not package omf files twice.
* Mon Feb 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Thu Dec 11 2008 coolo@suse.de
- require the translation package
* Sun Oct 26 2008 kkeil@suse.de
- Update to bugfix release 3.0.1
  * Fix crash on windows when using vsnprintf with a format string
    NULL. Happend when clicking the statusline
  * Add signal when unable to open any video output
  * Do not use a reference. It is preferable to copy the string.
  * Update calling states also on incoming call
  * Fixed device name
  * Default SIP presence is offline, not online
  * Fix flickering issues on XV due to the X Server's strange
    bookkeeping of used ports
  * Made libnotify optional
  * Fixed OPAL API breakage and raised requirements accordingly
  * Keep the preview thread for the lifetime of Ekiga
  * Fix possible X timing issue
  * Fix message box when device was unplugged in out-of-call state
  * Correctly hide addressbook and chat window when the user clicks
    close, various string/typo/translator comment fixes
* Wed Oct 15 2008 kkeil@suse.de
- Update to version 3.0.0 needed by GNOME 2.24 (bnc#428117)
  * Major version and API update with lot of bugfixes and new
    features
* Fri Mar 14 2008 maw@suse.de
- Update to version 2.0.12:
  + Fixed GNOME independent build
  + Fixed potential deadlock due to mutexes being crossed
    (bgo#433852)
  + Fixed double popup occuring when changing the DTMF mode during
    a call (bgo#485336)
  + Added back support for tooltips displayed in the statusbar
  + Fixed potential crash if gconfd is not running (bgo#498029)
- Drop ekiga-2.0.11.patch, as it's been upstreamed
- Split out a -lang subpackage
- Use %%fdupes.
* Fri Feb 29 2008 rodrigo@suse.de
- Upstream patches
* Thu Oct 11 2007 sbrabec@suse.cz
- Use binding specific avahi package.
* Wed Sep 19 2007 mauro@suse.de 
- Update to 2.0.11
  + Fixed V4L2 build. (Damien Sandras)
  + Killed GCC 4.2 warnings. (Damien Sandras)
* Mon Sep 17 2007 mauro@suse.de
- Update to 2.0.10
  - Fixed several interoperability issues due to bugs and limitations in
  - CISCO Call Manager. (Damien Sandras, #429076)
  - Decreased the default NAT binding refresh timeout. (Damien Sandras)
  - Fixed interoperability issue with SER+rtpproxy. (Damien Sandras, #430870)
  - Fixed the check for the installed GTK+ version in the WIN32
  installer. (Vincent Luba)
  - Fixed race condition when receiving an abnormal load of SIP text
  - messages. (Damien Sandras)
  - Fixed possible crash when opening V4L devices with 352x288 fixed width
  capability. (Luc Saillard, #434223).
  - Better handling of ACK requests timeouts. (Damien Sandras)
  - Fixed QOP authentication issues. (#368524, Knut omang)
  - Fixed Assertion fail in SetAttribute() if empty formats list and don't use
  deleted media session info when parsing fails. (Craig Southeren)
  - Refresh video capabilities when appropriate in the V4L plugin. (Michael
  Smith)
  - Fixed problems with the sa7134 card and with newer kernels in the V4L2
  plugin. (Michael Smith)
  - Do not use the loopback interface as possible interface on
  OpenSolaris. (Elaine Xiong from SUN, #439873)
  - Fixed routing of ACK requests sent for an INVITE with an original Route
  header. (Damien Sandras)
  - Optimized some color space conversions using MediaLib. (Elaine Xiong)
  - Fixed potential problems with MJPEG-based cameras. (Matthias Schneider)
  - Fixed possible remote crash due to fancy headers. (José Miguel Esparza)
* Sat May 12 2007 olh@suse.de
- remove unused libavc1394-devel libdc1394-devel from Buildrequires
* Fri Apr 27 2007 sbrabec@suse.cz
- Do not call meinproc (#227624).
* Tue Apr 24 2007 maw@suse.de
- Update to version 2.0.9
- Requires recent versions of opal and pwlib
- Fixes for bugzilla.gnome.org #421801, #418991, #419996, #419017,
  [#399378], #413979, and #405085.
* Thu Mar  8 2007 kkeil@suse.de
- new gconf2 schema installation
* Wed Feb 14 2007 kkeil@suse.de
- upgraded to 2.0.5 release
  * Fixed issues with some ALSA soundcards
  * Fixed potential security issue reported by MuSecurity
    (http://www.musecurity.com)
  * Fixed potential deadlock if no packets are received on the
    stream.(#404904, Hannes Friederich)
  * Remove fixed font coloring in codecs selection list
    (#405085, Mariano Suárez-Alvarez)
* Mon Jan 15 2007 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Fri Oct 13 2006 aj@suse.de
- Add gnome-doc-utils-devel to BuildRequires.
* Sat Oct  7 2006 aj@suse.de
- Cleanup BuildRequires.
- Use RPM_OPT_FLAGS for c++.
* Fri Sep 29 2006 kkeil@suse.de
- update to stable 2.0.3 release
  * Prevent infinite loop in the RTP session handler when being unable to write to the control port.(Damien Sandras)
  * Check for Expires header if not present in SIP contact field. (Damien Sandras)
  * Added HINTS for Logitech Quickcam Communicate. (Michael Riepe)
  * Allow '*', '+' and '#' to appear in user names in the accounts dialog.
  * Fixed call forwarding on no answer. (Damien Sandras)
  * Fixed delay after which an incoming call is rejected. (Damien Sandras)
  * Fixed call numbers inserted in the URL bar at the wrong place thanks. (Philippe Gassmann)
  * When executing the NAT test, and STUN is not suitable, remove the current STUN setting instead of leaving it as is.
  * Fixed possible crash on call release. (Drazen Dimoti)
  * Always limit the number of retries in case of registration failure. (Hannes Friederich)
  * Added support for the opaque attribute when authenticating. (Craig Southeren)
  * Added support for qop authentication. (Craig Southeren)
  * Fixed video suspend. (Damien Sandras)
  * Fixed crash when avahi is disabled for users (Julien Puydt with help from
    Sebastien Estienne and Lennart Poettering)
* Mon Aug 14 2006 sbrabec@suse.cz
- Provide and obsolete gnomemeeting.
- Enabled parallel build.
- Removed unneeded options.
- Fixed prefix clash.
- Bi-arch fix.
* Thu Aug 10 2006 kkeil@suse.de
-  first version (2.0.2) for autobuild
